Uses of Enum Class
io.codef.api.EasyCodefMessageConstant
-
Uses of EasyCodefMessageConstant in io.codef.api
Subclasses with type arguments of type EasyCodefMessageConstant in io.codef.apiModifier and TypeClassDescriptionenumio.codef.easycodef |_ EasyCodefMessageConstant.javaMethods in io.codef.api that return EasyCodefMessageConstantModifier and TypeMethodDescriptionstatic EasyCodefMessageConstantReturns the enum constant of this class with the specified name.static EasyCodefMessageConstant[]EasyCodefMessageConstant.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in io.codef.api with parameters of type EasyCodefMessageConstantModifier and TypeMethodDescriptionprotected voidEasyCodefResponse.setResultMessage(EasyCodefMessageConstant message) Desc : 요청 수행 결과 코드 설정Constructors in io.codef.api with parameters of type EasyCodefMessageConstantModifierConstructorDescriptionprotectedDesc : EasyCodefResponse 생성자protectedEasyCodefResponse(EasyCodefMessageConstant message, String extraMessage) Desc : EasyCodefResponse 생성자